diff lisp/progmodes/idlw-shell.el @ 111486:046351ea9819

Silence idlw*.el compilation. * lisp/progmodes/idlw-complete-structtag.el: Remove unused dec `name'. * lisp/progmodes/idlwave.el (idlwave-routine-entry-compare-twins) (idlwave-study-twins): Prefix dynamic local variable `name'. (idlwave-routine-twin-compare): Update for above change. * lisp/progmodes/idlw-help.el (idlwave-do-mouse-completion-help): Prefix dynamic local variables `name', `kwd', and `link'. * lisp/progmodes/idlw-shell.el (idlwave-shell-complete-execcomm-help): * lisp/progmodes/idlw-complete-structtag.el (idlwave-complete-structure-tag-help): * lisp/progmodes/idlwave.el (idlwave-complete-sysvar-help) (idlwave-complete-sysvar-tag-help) (idlwave-complete-class-structure-tag-help): Update for above name changes.
author Glenn Morris <rgm@gnu.org>
date Wed, 10 Nov 2010 19:53:16 -0800
parents 56b71cddc9c5
children b47e85affa59
line wrap: on
line diff
--- a/lisp/progmodes/idlw-shell.el	Thu Nov 11 03:50:27 2010 +0000
+++ b/lisp/progmodes/idlw-shell.el	Wed Nov 10 19:53:16 2010 -0800
@@ -2180,8 +2180,8 @@
       ;; Default completion of modules and keywords
       (idlwave-complete arg)))))
 
-;; Get rid of opaque dynamic variable passing of link?
-(defvar link) ;dynamic variable
+;; Get rid of opaque dynamic variable passing of idlw-help-link?
+(defvar idlw-help-link) ; dynamic variable from idlwave-do-mouse-completion-help
 (defun idlwave-shell-complete-execcomm-help (mode word)
   (let ((word (or (nth 1 idlwave-completion-help-info) word))
 	(entry (assoc-string word idlwave-executive-commands-alist t)))
@@ -2189,7 +2189,7 @@
      ((eq mode 'test)
       (and (stringp word) entry (cdr entry)))
      ((eq mode 'set)
-      (if entry (setq link (cdr entry)))) ;; setting dynamic variable!!!
+      (if entry (setq idlw-help-link (cdr entry)))) ; setting dynamic variable!
      (t (error "This should not happen")))))
 
 (defun idlwave-shell-complete-filename (&optional arg)